require 'uu/os/qos/qos_handler'
require 'uu/os/rest'
require 'uu/os/uesuri'
require 'uu/os/macro/macro_exec'
require 'uu/os/macro/macro_exec_options'

module UU
  module OS

      # Macro is representation of executable code in Unicorn Universe.
      module Macro
        extend self

        # Service path
        PATH = 'uu/os/Macro'

        # Executes macro based on main entity UESURI.
        #
        # @param [String, UU::OS::UESURI] main_entity_uri UESURI of main entity (either artifact or any aggregated object)
        # @param [MacroExec] parameters DTO containing macro execution parameters
        #
        # @return [UU::OS::REST::Future] UESURI of process in which the macro is executed
        def exec(main_entity_uri, parameters)
          svc = UU::OS::REST::RemoteClient.new(Macro)
          # Request is send as form data (server has problems with deserialization of DTO with object attributes)
          payload = UU::OS::Macro::MacroExec.new(parameters).to_hash
          UU::OS::QoS::QoSHandler.auto_retry do
            res = svc.post('exec', main_entity_uri, payload)
            return UU::OS::REST::Future.new(res)
          end
        end

      end

    end
end
