require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module OS
    module MetaModel
      # Meta Model Set Attributes DTO.
      # @deprecated Use {UU::OS::AppPackage::AppPackageSetAttributes} instead.
      class MetaModelSetAttributes < UU::OS::REST::DTO

        # The new name of the meta model. When null is set, the name is not modified.
        attr_accessor :name


        # The new description of the meta model. When null is set, the description is not modified.
        attr_accessor :description

        # The new security level of the meta model. When null is set, the security level is
        # not modified. If the meta model dictionary security level is higher than the user's
        # security clearance, the setAttributes command fails.
        attr_accessor :security_level

        # URI of the meta model's icon. When null is set, the meta model uses icon from meta
        # artifact.
        #
        # @example Allowed format of icon URI:
        #   ues:#{system}:#{ues_v5.core_v1.codetable_v1.base_v1.CodeTable_Icons}:#{CODE_OF_ICON}
        #
        # @example An example of icon URI:
        #   ues:#{system}:#{ues_v5.core_v1.codetable_v1.base_v1.CodeTable_Icons}:#{ART_077}
        attr_accessor :icon_uri
        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def security_level
          attributes[:securityLevel]
        end

        def security_level=(val)
          attributes[:securityLevel] = val
        end

        def icon_uri
          attributes[:iconUri]
        end

        def icon_uri=(val)
          if val
            attributes[:iconUri] = UU::OS::UESURI.new(val)
          else
            attributes[:iconUri] = nil
          end
        end

      end
    end

  end
end
