require 'uu/os/rest/dto'
require 'uu/os/uesuri'

# Module Unicorn Universe.
module UU
  # Module Operating System.
  module OS
    # Module Permission.
    module Permission
      # DTO containing attributes of the permission.
      class PermissionGetMaskAttributes < UU::OS::REST::DTO

        # UESURI of the permission mask.
        attr_accessor :uri

        # Name of the permission mask.
        attr_accessor :name

        # Code of the permission mask.
        attr_accessor :code

        # Description of the permission mask.
        attr_accessor :description

        # This flag specifies if the permission mask is set as the default permission mask in the specified meta artifact and is used as template for own permission settings.
        attr_accessor :default_mask

        # Creation time of the permission mask.
        attr_accessor :creation_time

        # Creation stamp of the permission mask.
        attr_accessor :creation_stamp

        # Modification time of the permission mask.
        attr_accessor :modification_time

        # Modification stamp of the permission mask.
        attr_accessor :modification_stamp

        # Version of the permission mask.
        attr_accessor :version

        # Labels of the permission mask in different languages.
        attr_accessor :labels

        def uri
          attributes[:uri]
        end

        def uri=(val)
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def default_mask
          attributes[:defaultMask]
        end

        def default_mask=(val)
          attributes[:defaultMask] = val
        end

        def creation_time
          attributes[:creationTime]
        end

        def creation_time=(val)
          attributes[:creationTime] = val
        end

        def creation_stamp
          attributes[:creationStamp]
        end

        def creation_stamp=(val)
          attributes[:creationStamp] = val
        end

        def modification_time
          attributes[:modificationTime]
        end

        def modification_time=(val)
          attributes[:modificationTime] = val
        end

        def modification_stamp
          attributes[:modificationStamp]
        end

        def modification_stamp=(val)
          attributes[:modificationStamp] = val
        end

        # @deprecated Use {PermissionGetMaskAttributes#version} instead.
        def revision 
          attributes[:version]
        end

        # @deprecated Use {PermissionGetMaskAttributes#version} instead.
        def revision=(val) 
          attributes[:version] = val
        end

        def version 
          attributes[:version]
        end

        def version=(val) 
          attributes[:version] = val
        end

        def labels
          attributes[:labels]
        end

        def labels=(val)
          attributes[:labels] = val
        end

      end
    end

  end
end

