require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module OS
    module UUEE
      class UUEEAttributes < UU::OS::REST::DTO

        # Normalized UESURI of the uuEE. Never nil.
        attr_accessor :uri

        # First name of the uuEE. Never nil.
        attr_accessor :first_name

        # Surname of the uuEE. Never nil.
        attr_accessor :surname

        # Code of the uuEE. Never nil.
        attr_accessor :code

        # Description of the uuEE.
        attr_accessor :description

        # URI of the uuEE's container. Never nil.
        attr_accessor :location_uri

        # URI of the organizational unit in which the uuEE lies. Never nil.
        attr_accessor :organizational_unit_uri

        # URI of the company in which the uuEE lies. Never nil.
        # @deprecated
        attr_accessor :company_uri

        # URI of the meta artifact. Never nil.
        attr_accessor :meta_artifact_uri

        # Universe identifier of the user. Never nil.
        attr_accessor :universe_id

        # URI of the competent role. Never nil.
        attr_accessor :competent_role_uri

        # Security level of the uuEE. Never nil.
        attr_accessor :security_level

        # Security clearance of the uuEE. Never nil.
        attr_accessor :security_clearance

        # Creation stamp of the uuEE.
        attr_accessor :creation_stamp

        # Creation time of the uuEE.
        attr_accessor :creation_time

        # Modification stamp of the uuEE.
        attr_accessor :modification_stamp

        # Modification time of the uuEE.
        attr_accessor :modification_time

        # Version of the uuEE.
        attr_accessor :version

        # Specifies if it is possible to search the uuEE in its territory.
        attr_accessor :searchable_in_territory

        # URI of the uuEE's icon. When nil is set, the role uses icon from meta artifact.
        attr_accessor :icon_uri

        # @deprecated Specifies if the uuEE is be included among All roles from organizational
        # unit. Never nil.
        attr_accessor :grant_all_from_organizational_unit

        # UESURI of the entity type of the uuEE. Never nil.
        attr_accessor :entity_type_uri

        # State type of the uuEE. Never nil.
        attr_accessor :state_type
        
        # @deprecated Always returns nil.
        attr_accessor :artifact_type
        
        # Indicates whether the primarily displayed content of the uuEE is component content.
        attr_accessor :component_content
        
        # Full code of the application which is represented by the uuEE. The code is in the format VENDOR_CODE.APP_CODE. If the value is not set, the uuEE is not an identity of any application.
        attr_accessor :app_code
        
        # UESURI or URL of image which represents uuEE's avatar (user photo).
        attr_accessor :avatar_uri

        # @deprecated Always returns nil.
        def artifact_type
          nil
        end

        # @deprecated Input value is ignored, nil is always assumed.
        def artifact_type=(val)
        end
        
        def uri
          attributes[:uri]
        end

        def uri=(val)
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end

        def first_name
          attributes[:firstName]
        end

        def first_name=(val)
          attributes[:firstName] = val
        end

        def surname
          attributes[:surname]
        end

        def surname=(val)
          attributes[:surname] = val
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def location_uri
          attributes[:locationUri]
        end

        def location_uri=(val)
          if val
            attributes[:locationUri] = UU::OS::UESURI.new(val)
          else
            attributes[:locationUri] = nil
          end
        end

        def organizational_unit_uri
          attributes[:organizationalUnitUri]
        end

        def organizational_unit_uri=(val)
          if val
            attributes[:organizationalUnitUri] = UU::OS::UESURI.new(val)
          else
            attributes[:organizationalUnitUri] = nil
          end
        end

        # @deprecated
        def company_uri
          attributes[:companyUri]
        end

        # @deprecated
        def company_uri=(val)
          if val
            attributes[:companyUri] = UU::OS::UESURI.new(val)
          else
            attributes[:companyUri] = nil
          end
        end

        def meta_artifact_uri
          attributes[:metaArtifactUri]
        end

        def meta_artifact_uri=(val)
          if val
            attributes[:metaArtifactUri] = UU::OS::UESURI.new(val)
          else
            attributes[:metaArtifactUri] = nil
          end
        end

        def universe_id
          attributes[:universeId]
        end

        def universe_id=(val)
          attributes[:universeId] = val
        end

        def competent_role_uri
          attributes[:competentRoleUri]
        end

        def competent_role_uri=(val)
          if val
            attributes[:competentRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:competentRoleUri] = nil
          end
        end

        def security_level
          attributes[:securityLevel]
        end

        def security_level=(val)
          attributes[:securityLevel] = val
        end

        def security_clearance
          attributes[:securityClearance]
        end

        def security_clearance=(val)
          attributes[:securityClearance] = val
        end

        def creation_stamp
          attributes[:creationStamp]
        end

        def creation_stamp=(val)
          attributes[:creationStamp] = val
        end

        def creation_time
          attributes[:creationTime]
        end

        def creation_time=(val)
          attributes[:creationTime] = val
        end

        def modification_stamp
          attributes[:modificationStamp]
        end

        def modification_stamp=(val)
          attributes[:modificationStamp] = val
        end

        def modification_time
          attributes[:modificationTime]
        end

        def modification_time=(val)
          attributes[:modificationTime] = val
        end

        # @deprecated Use {UUEEAttributes#version} instead.
        def revision
          attributes[:version]
        end

        # @deprecated Use {UUEEAttributes#version} instead.
        def revision=(val)
          attributes[:version] = val
        end

        def version
          attributes[:version]
        end

        def version=(val)
          attributes[:version] = val
        end

        def searchable_in_territory
          attributes[:searchableInTerritory]
        end

        def searchable_in_territory=(val)
          attributes[:searchableInTerritory] = val
        end

        def icon_uri
          attributes[:iconUri]
        end

        def icon_uri=(val)
          if val
            attributes[:iconUri] = UU::OS::UESURI.new(val)
          else
            attributes[:iconUri] = nil
          end
        end

        def grant_all_from_organizational_unit
          attributes[:grantAllFromOrganizationalUnit]
        end

        def grant_all_from_organizational_unit=(val)
          attributes[:grantAllFromOrganizationalUnit] = val
        end

        def entity_type_uri
          attributes[:entityTypeUri]
        end

        def entity_type_uri=(val)
          if val
            attributes[:entityTypeUri] = UU::OS::UESURI.new(val)
          else
            attributes[:entityTypeUri] = nil
          end
        end

        def state_type
          attributes[:stateType]
        end

        def state_type=(val)
          attributes[:stateType] = val
        end
        
        def component_content
          attributes[:componentContent]
        end
       
        def component_content=(val)
          attributes[:componentContent] = val
        end
        
        def app_code
          attributes[:appCode]
        end
              
        def app_code=(val)
          attributes[:appCode] = val
        end
        
        def avatar_uri
          attributes[:avatarUri]
        end
              
        def avatar_uri=(val)
          attributes[:avatarUri] = val
        end

      end
    end

  end

end
